package controller

import (
	"gas-cylinder-api/app/admin/model"
	"gas-cylinder-api/app/admin/service"
	"gas-cylinder-api/app/admin/service/dto"
	"gas-cylinder-api/common/actions"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
	"gogs.baozhida.cn/zoie/OAuth-core/api"
	"gogs.baozhida.cn/zoie/OAuth-core/pkg/jwtauth/user"
	_ "gogs.baozhida.cn/zoie/OAuth-core/pkg/response"
)

type FillCheckController struct {
	api.Api
}

// GetPage 获取充气前后检查列表
// @Summary 获取充气前后检查列表
// @Description 获取充气前后检查列表
// @Tags 充气前后检查
// @Param innerCode query string false "单位内编码"
// @Param pageSize query int false "页条数"
// @Param page query int false "页码"
// @Success 200 {object} response.Response{data=response.Page{list=[]model.FillCheck}} "{"code": 200, "data": [...]}"
// @Router /api/fill-check [get]
// @Security Bearer
func (e FillCheckController) GetPage(c *gin.Context) {
	s := service.FillCheck{}
	req := dto.FillCheckGetPageReq{}
	err := e.MakeContext(c).
		MakeOrm().
		Bind(&req, binding.Query).
		MakeService(&s.Service).
		Errors
	if err != nil {
		e.Logger.Error(err)
		e.Error(500, err, err.Error())
		return
	}

	//数据权限检查
	p := actions.GetPermissionFromContext(c)

	list := make([]model.FillCheck, 0)
	var count int64

	err = s.GetPage(&req, &list, &count, p)
	if err != nil {
		e.Error(500, err, err.Error())
		return
	}
	e.PageOK(list, int(count), req.GetPageIndex(), req.GetPageSize(), "查询成功")
}

// Get 通过id获取充气前后检查
// @Summary 通过id获取充气前后检查
// @Description 通过id获取充气前后检查
// @Tags 充气前后检查
// @Param id path string true "充气前后检查id"
// @Success 200 {object} response.Response{data=model.FillCheck} "{"code": 200, "data": [...]}"
// @Router /api/fill-check/{id} [get]
// @Security Bearer
func (e FillCheckController) Get(c *gin.Context) {
	s := service.FillCheck{}
	req := dto.FillCheckGetReq{}
	err := e.MakeContext(c).
		MakeOrm().
		Bind(&req, nil).
		MakeService(&s.Service).
		Errors
	if err != nil {
		e.Logger.Error(err)
		e.Error(500, err, err.Error())
		return
	}
	var object model.FillCheck
	p := actions.GetPermissionFromContext(c)

	//数据权限检查
	err = s.Get(&req, &object, p)
	if err != nil {
		e.Error(500, err, err.Error())
		return
	}

	e.OK(object, "查询成功")
}

// Insert 添加充气前后检查
// @Summary 添加充气前后检查
// @Description 添加充气前后检查
// @Tags 充气前后检查
// @Accept  application/json
// @Product application/json
// @Param data body dto.FillCheckInsertReq true "data"
// @Success 200 {string} string	"{"code": 200, "message": "添加成功"}"
// @Success 200 {string} string	"{"code": -1, "message": "添加失败"}"
// @Router /api/fill-check [post]
// @Security Bearer
func (e FillCheckController) Insert(c *gin.Context) {
	s := service.FillCheck{}
	userSvc := service.SysUser{}
	req := dto.FillCheckInsertReq{}
	err := e.MakeContext(c).
		MakeOrm().
		Bind(&req, binding.JSON).
		MakeService(&s.Service).
		MakeService(&userSvc.Service).
		Errors
	if err != nil {
		e.Logger.Error(err)
		e.Error(500, err, err.Error())
		return
	}

	// 设置创建人
	req.SetCreateBy(user.GetUserId(c))
	req.SetDeptId(user.GetDeptId(c))

	var userObj model.SysUser
	err = userSvc.Get(&dto.SysUserGetReq{Id: user.GetUserId(c)}, nil, &userObj)
	if err != nil {
		e.Error(500, err, err.Error())
		return
	}

	req.StoreId = userObj.ProvUser.CmpCode
	req.CreatorId = userObj.ProvUserId
	req.UserId = userObj.Id
	err = s.Insert(&req)
	if err != nil {
		e.Error(500, err, err.Error())
		return
	}
	e.OK(req.GetId(), "创建成功")
}
