package model

import (
	"database/sql/driver"
	"encoding/json"
	model2 "gas-cylinder-api/common/model"
)

// 省平台运输企业
type ProvCarInfo struct {
	CarNo          string `json:"carNo" gorm:"size:32;" vd:"@:len($)>0;msg:'车牌号不能为空'"` // 车牌号
	TransportTime  string `json:"transportTime" gorm:"size:10;" `                      // 道路运输证有效期
	CarNumber      string `json:"carNumber" gorm:"size:32;"`                           // 道路运输证编号
	CarLoadage     string `json:"carLoadage" gorm:"size:128;"`                         // 车辆核定载货量
	CarNvq         string `json:"carNvq" gorm:"size:32;"`                              // 车辆资格证
	TypeTransport  string `json:"typeTransport" gorm:"size:64;"`                       // 车辆运输类型
	BusinessName   string `json:"businessName" gorm:"size:128;"`                       // 业户名称
	ContactNumber  string `json:"contactNumber" gorm:"size:32;"`                       // 联系电话
	IssueAuthority string `json:"issueAuthority" gorm:"size:128;"`                     // 发证机关
	CmpCode        string `json:"cmpCode" gorm:"size:36;"`                             // 归属企业登记编号
}
type CarInfo struct {
	model2.Model
	CarNo            string           `json:"carNo" gorm:"size:32;"`   // 车牌号
	CmpCode          string           `json:"cmpCode" gorm:"size:36;"` // 归属企业登记编号
	ProvCarInfo      ProvCarInfo      `json:"provCarInfo"`
	TruckUserCarInfo TruckUserCarInfo `json:"truckUserCarInfo"  gorm:"->;foreignkey:CarNo;references:CarNo;"`
	model2.ControlBy
	model2.ModelTime
	model2.DeptBy
}

func (CarInfo) TableName() string {
	return "car_info"
}

func (e *CarInfo) Generate() model2.ActiveRecord {
	o := *e
	return &o
}

func (e *CarInfo) GetId() interface{} {
	return e.Id
}

func (e ProvCarInfo) Value() (driver.Value, error) {
	d, err := json.Marshal(e)
	return string(d), err
}

func (e *ProvCarInfo) Scan(src interface{}) error {
	return json.Unmarshal(src.([]byte), e)
}
