package model

import model2 "gas-cylinder-api/common/model"

type ProvGasCylinder struct {
	ProVariety        string `json:"pro_variety"`        // 设备品种
	ProName           string `json:"pro_name"`           // 产品名称
	ProNo             string `json:"pro_no"`             // 气瓶生产编号
	FillMedia         int    `json:"fill_media"`         // 充装介质：0液化石油气，1二甲醚，2氧气，3二氧化碳，4溶解乙炔
	MakeUnit          string `json:"make_unit"`          // 制造单位
	MakeTime          string `json:"make_time"`          // 生产日期
	WorkPressure      int    `json:"work_pressure"`      // 公称工作压口(MPa)
	Volume            int    `json:"volume"`             // 容积(L)
	CheckTime         string `json:"check_time"`         // 最近一次检验日期(新瓶该值填写出厂日期)
	NextCheckTime     string `json:"next_check_time"`    // 下次检验日期(液化石油气瓶顺延4年气瓶下一次需要送检验站检验的日期)
	RegistCode        string `json:"regist_code"`        // 气瓶使用登记代码
	ChangeEvent       string `json:"change_event"`       // 变更情况(主要记录产权过户日志)
	Memo              string `json:"memo"`               // 备注
	InnerCode         string `json:"inner_code"`         // 单位内编号
	StampMakeUnit     string `json:"stamp_make_unit"`    // 气瓶钢印制造单位名称
	ProUuid           string `json:"pro_uuid"`           // 产品唯一性编码
	ChipId            string `json:"chip_id"`            // 芯片id(每一个批次生成的登记证编号)
	Location          string `json:"location"`           // 归属地(客户、门店、气站、检测机构): 0001 门店，0002 气站，0003 企业，0004 检验机构，005 移动库，006 客户
	Status            string `json:"status"`             // 气瓶状态[在用(已检测)、停用(待检测)、报废]:submit新瓶提交，using在用(已检测)，stop停用(待检测)，scrapped报废
	CheckOrganization string `json:"check_organization"` // 检测机构
	EmptyBottle       bool   `json:"empty_bottle"`       // 是否空瓶：0是，1不是
	Uid               string `json:"uid"`                // 高频编码
	Tid               string `json:"tid"`                // 超高频编码
	ChipStatus        bool   `json:"chip_status"`        // 是否改造：0未改造，1已改造
	LocationSourceId  string `json:"location_source_id"` // 当前归属机构ID
	IsLose            bool   `json:"is_lose"`            // 是否丢失：0丢失，1未丢失
	OldBottle         bool   `json:"old_bottle"`         // 是否旧瓶
	DesignThickness   int    `json:"design_thickness"`   // 设计壁厚
	ResultCode        string `json:"result_code"`        // 检测结果
	AuditRemark       string `json:"audit_remark"`       // 审批备注
	DeadlineTime      string `json:"deadline_time"`      // 使用年限
	CheckInTime       string `json:"check_in_time"`      // 录入日期
	ScrapTime         string `json:"scrap_time"`         // 报废日期
	AnalysisStatus    string `json:"analysis_status"`    // 统计状态值：inform已提交待审批，using在用，scrapped报废
	CheckStatus       bool   `json:"check_status"`       // 1已证，0未证
	OperationId       string `json:"operation id"`       // 操作人id
	OperationTime     string `json:"operation time"`     // 操作时间
	SafeEvaluate      bool   `json:"safe_evaluate"`      // 安全评定
}

type GasCylinder struct {
	model2.Model
	InnerCode             string `json:"inner_code"`              // 1单位内编号
	Uid                   string `json:"uid"`                     // 高频编码 暂时无法获取 同单位内编号
	StationName           string `json:"station_name"`            // 上次充装气站
	FillTime              string `json:"fill_time"`               // 上次充装时间
	RegisterSuperviseName string `json:"register_supervise_name"` // 使用登记审批单位
	RegisterTime          string `json:"register_time"`           // 使用登记日期
	ProVariety            string `json:"pro_variety"`             // 1设备品种
	EnterpriseName        string `json:"enterprise_name"`         // 产权单位
	ProName               string `json:"pro_name"`                // 1产品名称
	ProNo                 string `json:"pro_no"`                  // 1气瓶生产编号 (出厂)编号
	FillMedia             string `json:"fill_media"`              // 1充装介质：0液化石油气，1二甲醚，2氧气，3二氧化碳，4溶解乙炔
	MakeUnit              string `json:"make_unit"`               // 1制造单位
	MakeTime              string `json:"make_time"`               // 1生产日期
	WorkPressure          string `json:"work_pressure"`           // 1公称工作压口(MPa)
	Volume                string `json:"volume"`                  // 1容积(L)
	CheckTime             string `json:"check_time"`              // 1最近一次检验日期(新瓶该值填写出厂日期)
	NextCheckTime         string `json:"next_check_time"`         // 1下次检验日期(液化石油气瓶顺延4年气瓶下一次需要送检验站检验的日期)
	ProUuid               string `json:"pro_uuid"`                // 1产品唯一性编码
	StoreName             string `json:"store_name"`              // 所属二级配送站
	CirOwnerName          string `json:"cir_owner_name"`          // 当前流转归属于
	ChangeEvent           string `json:"change_event"`
	Memo                  string `json:"memo"`
	AliasName             string `json:"alias_name"`
	Status                string `json:"status"`

	LastOperationTime model2.Time `json:"last_operation_time"` // 最新操作时间
	model2.ControlBy
	model2.ModelTime
	model2.DeptBy
}

func (GasCylinder) TableName() string {
	return "gas_cylinder"
}
