package dto

import (
	"gas-cylinder-api/app/admin/model"
	"gas-cylinder-api/common/dto"
	common "gas-cylinder-api/common/model"
)

type CarInfoGetPageReq struct {
	dto.Pagination     `search:"-"`
	CarNo              string `form:"carNo" search:"type:contains;column:car_no;table:car_info"` // 车牌号
	StartTransportTime string `form:"startTransportTime" search:"-"`                             // 道路运输证有效期
	EndTransportTime   string `form:"endTransportTime" search:"-"`                               // 道路运输证有效期
	CarInfoOrder
}

type CarInfoOrder struct {
	CreatedAtOrder string `search:"type:order;column:created_at;table:car_info" form:"createdAtOrder" default:"desc"`
}

func (m *CarInfoGetPageReq) GetNeedSearch() interface{} {
	return *m
}

type CarInfoInsertReq struct {
	Id               int               `json:"id" comment:"编码" swaggerignore:"true"` // 编码
	CarNo            string            `json:"carNo" swaggerignore:"true"`           // 车牌号
	CmpCode          string            `json:"cmpCode" swaggerignore:"true"`         // 归属企业登记编号
	ProvCarInfo      model.ProvCarInfo `json:"provCarInfo"`
	common.ControlBy `swaggerignore:"true"`
	common.DeptBy    `swaggerignore:"true"`
}

func (s *CarInfoInsertReq) Generate(model *model.CarInfo) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.CarNo = s.ProvCarInfo.CarNo
	model.CmpCode = s.ProvCarInfo.CmpCode
	model.ProvCarInfo = s.ProvCarInfo
	if s.ControlBy.UpdateBy != 0 {
		model.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		model.CreateBy = s.CreateBy
	}
	if s.DeptBy.DeptId != 0 {
		model.DeptId = s.DeptId
	}
}

func (s *CarInfoInsertReq) GetId() interface{} {
	return s.Id
}
func (s *CarInfoInsertReq) SetCmpCode(cmpCode string) {
	s.ProvCarInfo.CmpCode = cmpCode
}

type CarInfoUpdateReq struct {
	Id               int               `json:"id" comment:"编码"`            // 编码
	CarNo            string            `json:"carNo" swaggerignore:"true"` // 车牌号
	ProvCarInfo      model.ProvCarInfo `json:"provCarInfo"`
	common.ControlBy `swaggerignore:"true"`
}

func (s *CarInfoUpdateReq) Generate(model *model.CarInfo) {
	if s.Id != 0 {
		model.Id = s.Id
	}
	model.CarNo = s.ProvCarInfo.CarNo
	model.ProvCarInfo = s.ProvCarInfo
	if s.ControlBy.UpdateBy != 0 {
		model.UpdateBy = s.UpdateBy
	}
	if s.ControlBy.CreateBy != 0 {
		model.CreateBy = s.CreateBy
	}
}

func (s *CarInfoUpdateReq) GetId() interface{} {
	return s.Id
}

type CarInfoGetReq struct {
	Id int `uri:"id"`
}

func (s *CarInfoGetReq) GetId() interface{} {
	return s.Id
}

type CarInfoDeleteReq struct {
	Id               int `json:"id"`
	common.ControlBy `swaggerignore:"true"`
}

func (s *CarInfoDeleteReq) GetId() interface{} {
	return s.Id
}

type CarInfoBindTruckUserReq struct {
	CarNo            string `json:"carNo"`
	UserId           string `json:"userId"`
	common.ControlBy `swaggerignore:"true"`
}
